=====================================
Installing OpenStack DNS as a Service
=====================================

Manual Designate installation
-----------------------------

This chapter assumes a working setup of OpenStack following the
`OpenStack Installation Tutorial <https://docs.openstack.org/install/>`_.

.. toctree::
   :maxdepth: 2

   get_started
   install
   verify
   create-zone
   next-steps

Quickstart with Kolla
---------------------

Following the `Designate in Kolla
<https://docs.openstack.org/kolla-ansible/latest/reference/networking/designate-guide.html>`_
to quickly install and setup Designate.
